@@ -35,10 +35,10 @@
 #include "scriptedfileformat.h"
 #include "scriptedtool.h"
 #include "scriptfileformatwrappers.h"
+#include "scriptimage.h"
 #include "scriptmanager.h"
 #include "tilesetdocument.h"
 #include "tileseteditor.h"
-#include "world.h"
 #include "worlddocument.h"
 #include "worldmanager.h"
 
@@ -290,6 +290,21 @@ QVariant ScriptModule::propertyValue(const QString &typeName, const QJSValue &va
     return type->wrap(var);
 }
 
+QCursor ScriptModule::cursor(Qt::CursorShape shape)
+{
+    return shape;
+}
+
+QCursor ScriptModule::cursor(ScriptImage *image, int hotX, int hotY)
+{
+    if (!image) {
+        ScriptManager::instance().throwNullArgError(0);
+        return {};
+    }
+
+    return QCursor { QPixmap::fromImage(image->image()), hotX, hotY };
+}
+
 bool ScriptModule::versionLessThan(const QString &a, const QString &b)
 {
     return QVersionNumber::fromString(a) < QVersionNumber::fromString(b);
@@ -730,10 +745,8 @@ QList<QObject *> ScriptModule::worlds() const
     if (!documentManager)
         return worlds;
 
-    for (const World *world : WorldManager::instance().worlds()) {
-        WorldDocument *worldDocument = documentManager->ensureWorldDocument(world->fileName);
+    for (auto &worldDocument : WorldManager::instance().worlds())
         worlds.append(worldDocument->editable());
-    }
 
     return worlds;
 }
@@ -745,7 +758,8 @@ void ScriptModule::loadWorld(const QString &fileName) const
 
 void ScriptModule::unloadWorld(const QString &fileName) const
 {
-    WorldManager::instance().unloadWorld(fileName);
+    if (auto worldDocument = WorldManager::instance().findWorld(fileName))
+        WorldManager::instance().unloadWorld(worldDocument);
 }
 
 void ScriptModule::unloadAllWorlds() const
